@@ -264,7 +264,7 @@ static int log_add_file(log_t *logdata, const char *destination,
 	char *canonical_fname = NULL;
 	logfile_t *lf = NULL;
 
-	if (conf_log) {
+	if (logdata->log_to_file) {
 		if (log_has_file(logdata, filename)) {
 			canonical_fname = bip_strdup(filename);
 			uniq_fname = filename_uniq(filename);
@@ -309,7 +309,7 @@ static int log_add_file(log_t *logdata, const char *destination,
 		hash_insert(&logdata->logfgs, destination, store);
 	}
 
-	if (!conf_log && logdata->user->backlog) {
+	if (!logdata->log_to_file && logdata->user->backlog) {
 		if (!store->memlog)
 			store->memlog = list_new(NULL);
 	}
@@ -347,11 +347,11 @@ logstore_t *log_find_file(log_t *logdata, const char *destination)
 
 	store = hash_get(&logdata->logfgs, destination);
 
-	if (store && !conf_log)
+	if (store && !logdata->log_to_file)
 		return store;
 
 	if (!store) {
-		if (conf_log) {
+		if (logdata->log_to_file) {
 			filename = log_build_filename(logdata, destination);
 			if (!filename)
 				return NULL;
@@ -359,7 +359,8 @@ logstore_t *log_find_file(log_t *logdata, const char *destination)
 					destination, filename);
 		}
 		if (!log_add_file(logdata, destination, filename)) {
-			free(filename);
+		    if (filename)
+			    free(filename);
 			return NULL;
 		}
 		store = hash_get(&logdata->logfgs, destination);
@@ -474,10 +475,14 @@ void log_nick(log_t *logdata, const char *ircmask, const char *channel,
 		const char *newnick)
 {
 	char *oldnick = nick_from_ircmask(ircmask);
+	logstore_t* oldstore;
+	logstore_t* newstore;
 
-	if (hash_includes(&logdata->logfgs, oldnick)) {
-		if (hash_includes(&logdata->logfgs, newnick))
+	if ((oldstore = hash_get(&logdata->logfgs, oldnick))) {
+		if ((newstore = hash_get(&logdata->logfgs, newnick))
+			&& oldstore != newstore) {
 			log_drop(logdata, newnick);
+		}
 		hash_rename_key(&logdata->logfgs, oldnick, newnick);
 	}
 	free(oldnick);
@@ -528,13 +533,7 @@ static void do_log_privmsg(log_t *logdata, const char *storage, int src,
 void log_privmsg(log_t *logdata, const char *ircmask, const char *destination,
 		const char *message)
 {
-	if (!ischannel(*destination)) {
-		char *nick = nick_from_ircmask(ircmask);
-		do_log_privmsg(logdata, nick, 0, ircmask, message);
-		free(nick);
-	} else {
-		do_log_privmsg(logdata, destination, 0, ircmask, message);
-	}
+	do_log_privmsg(logdata, destination, 0, ircmask, message);
 }
 
 void log_cli_privmsg(log_t *logdata, const char *ircmask,
@@ -1079,7 +1078,7 @@ static list_t *log_backread(log_t *log, const char *storename, const char *dest)
 		return ret;
 	}
 
-	if (!conf_log) {
+	if (!log->log_to_file) {
 		mylog(LOG_DEBUG, "No conf_log, not backlogging");
 		return NULL;
 	}
@@ -1139,7 +1138,7 @@ static int _log_write(log_t *logdata, logstore_t *store,
 		}
 	}
 
-	if (!conf_log)
+	if (!logdata->log_to_file)
 		return 0;
 
 	logfile_t *lf = list_get_last(&store->file_group);
@@ -1195,7 +1194,7 @@ void log_flush_all(void)
 	}
 }
 
-log_t *log_new(struct user *user, const char *network)
+log_t *log_new(struct bipuser *user, const char *network)
 {
 	log_t *logdata;
 
@@ -1207,6 +1206,7 @@ log_t *log_new(struct user *user, const char *network)
 	logdata->buffer[LOGLINE_MAXLEN - 1] = 0; // debug
 	logdata->buffer[LOGLINE_MAXLEN] = 0;
 	logdata->connected = 0;
+	logdata->log_to_file = conf_log;
 	if (!log_all_logs)
 		log_all_logs = list_new(list_ptr_cmp);
 	list_add_last(log_all_logs, logdata);
@@ -1315,6 +1315,8 @@ static list_t *log_backread_hours(log_t *log, const char *storename,
 	blstarttime = tv.tv_sec - 3600 * hours;
 
 	store = hash_get(&log->logfgs, storename);
+	if (!store)
+		return NULL;
 
 	ret = list_new(NULL);
 	for (logstore_get_file_at(store, blstarttime, &file_it);
